@@ -16,22 +16,15 @@ __copyright__ = """
 * EXPRESSLY ADVISED OF SUCH LOSS OR DAMAGE.
 """
 import socket
-import subprocess
-
+import os
 
 def getfqdn():
     return socket.getaddrinfo(socket.gethostname(), 0, 0, 0, 0, socket.AI_CANONNAME)[0][3]
 
 def getcontainerid():
     temp = None
-    containerid = None
-    temp = subprocess.check_output(
-            "grep docker -m1 /proc/self/cgroup|echo $(read s;s=${s##*/};s=${s#*docker-};s=${s%.scope};echo $s)",
-            shell=True)
-    containerid = temp.decode()
-    if containerid == '\n':
-       containerid = None
+    result = os.environ['CONTAINERID']
+    if result == 'None':
+        return temp
     else:
-       containerid = containerid.strip('\n')
-       
-    return containerid
+        return result
